<?php
session_start();

function getEmployees($ref) {
    $db = new PDO('sqlite:chinook.db');
    $query = '
        SELECT *
        FROM employees
    ';
    $params = array();

    if ($ref == null) {
        $query .= ' WHERE ReportsTo IS NULL';
    } else {
        $query .= ' WHERE ReportsTo = ?';
        $params = array($ref);
    }

    $stmt = $db->prepare($query);
    $stmt->execute($params);

    $employees = $stmt->fetchAll(PDO::FETCH_ASSOC);

    foreach ($employees as $key => $employee) {
        $employees[$key]['children'] = getEmployees($employee['EmployeeId']);
    }

    return $employees;
}

function renderEmployees($employees, $selected) {
    if ($employees == null || count($employees) == 0) return "";

    ?><ul class="employees">
        <?php foreach ($employees as $employee) { ?>
            <li>
                <details <?= $employee['EmployeeId'] == $selected ? "open" : "" ?>>
                    <summary><strong><?= $employee['LastName'] ?>, <?= $employee['FirstName'] ?></strong> (<?= $employee['Title'] ?>)</summary>
                    <address>
                        Address:<br/>
                        <?= $employee['Address'] ?><br/>
                        <?= $employee['PostalCode'] ?>, <?= $employee['City'] ?><br/>
                        <?= $employee['Country'] ?>, <?= $employee['State'] ?><br/>
                        <br/>
                        EMail: <a href="mailto:<?= $employee['Email'] ?>"><?= $employee['Email'] ?>, <?= $employee['FirstName'] ?></a><br/>
                        Phone: <a href="tel:<?= $employee['Phone']?>"><?= $employee['Phone']?></a><br/>
                        Fax: <a href="tel:<?= $employee['Fax']?>"><?= $employee['Fax']?></a>
                    </address>
                </details>
                <?= renderEmployees($employee['children'], $selected) ?>
            </li>
        <?php } ?>
    </ul><?php
}
?>
<!doctype html>
<html>
    <head>
        <title>Chinook Mediendatenbank</title>
        <link rel="stylesheet" href="style.css" />
    </head>
    <body>
        <nav><?php include('menu.inc.php'); ?></nav>
        <main>
            <h2>Mitarbeiter</h2>
            <?php if (isset($_SESSION['user'])) { ?>
                <?= renderEmployees(getEmployees(null), empty($_GET['id']) ? null : $_GET['id']) ?>
            <?php } else { ?>
                Bitte <a href="login.php">anmelden</a>!
            <?php } ?>
        </main>
    </body>
</html>