<?php
session_start();

$db = new PDO('sqlite:chinook.db');

$stmt = $db->prepare('
    SELECT
        invoices.customerID AS id,
        lastName || ", " || firstName AS name,
        address AS address,
        COUNT(*) as invoiceCount,
        SUM(total) as invoiceTotal
    FROM customers, invoices
    WHERE invoices.customerID = customers.customerID
    GROUP BY customers.customerID
    ORDER BY name ASC
');
$stmt->execute([]);
$customers = $stmt->fetchAll(PDO::FETCH_ASSOC);

$customerID = -1;

if (isset($_GET['customerID'])) {
    $customerID = $_GET['customerID'];
}

$stmt = $db->prepare('
    SELECT
    customers.lastName || ", " || customers.firstName AS Customer,
    employees.lastName || ", " || employees.firstName || " (" || employees.title || ")" AS SupportRep,
    invoices.*
    FROM invoices, customers, employees
    WHERE invoices.customerid = ?
    AND invoices.customerid = customers.customerid
    AND customers.supportrepid = employees.employeeid
    ORDER BY Customer, InvoiceDate;
');
$stmt->execute([$customerID]);
$data = $stmt->fetchAll(PDO::FETCH_ASSOC);

?>
<!doctype html>
<html>
    <head>
        <title>Chinook Mediendatenbank</title>
        <link rel="stylesheet" href="style.css" />
    </head>
    <body>
        <nav><?php include('menu.inc.php'); ?></nav>
        <main>
            <h2>Rechnungen</h2>
            <?php if (isset($_SESSION['user'])) { ?>
                
                <form action="<?= $_SERVER['PHP_SELF']; ?>" method="get">
                    <label>
                        Kunden auswählen:
                        <select name="customerID" onchange="this.form.submit()" autofocus>
                            <option value="-1" <?= $customerID == -1 ? 'selected' : '' ?>>&raquo; bitte auswählen &laquo;</option>
                            <?php foreach ($customers as $value) { ?>
                                <option value="<?= $value['id'] ?>" <?= $customerID == $value['id'] ? 'selected' : '' ?>>
                                    <?= $value['name'] ?> - <?= $value['address'] ?> (<?= $value['invoiceCount'] ?> Rechnungen mit insg. <?= $value['invoiceTotal'] ?> € Gesamtwert)
                                </option>
                            <?php } ?>
                        </select>
                    </label>
                </form>

                <p>&nbsp;</p>

                <table>
                    <tr>
                        <th>Datum</th>
                        <th>Total</th>
                        <th>SupportRep</th>
                        <th>BillingAdress</th>
                    </tr>
                    <?php foreach ($data as $value) { ?>   
                        <tr>
                            <td><?= $value['InvoiceDate'] ?></td>
                            <td><?= $value['Total'] ?></td>
                            <td><?= $value['SupportRep'] ?></td>
                            <td>
                                <address>
                                    <?= $value['BillingAddress'] ?><br/>
                                    <?= $value['BillingPostalCode'] ?>, <?= $value['BillingCity'] ?><br/>
                                    <?= $value['BillingState'] ?>, <?= $value['BillingCountry'] ?>
                                </address>
                            </td>
                        </tr>
                    <?php } ?>
                </table>
            <?php } else { ?>
                Bitte <a href="login.php">anmelden</a>!
            <?php } ?>
        </main>
    </body>
</html>