<?php

require_once 'helpers.inc.php';

session_start();

$db = new PDO('sqlite:chinook.db');

$stmt = $db->prepare('
    SELECT playlists.*, COUNT(playlists.playlistid) AS TrackCount, SUM(tracks.milliseconds) AS Duration
    FROM playlists, playlist_track, tracks
    WHERE playlist_track.playlistid = playlists.playlistid
    AND tracks.trackid = playlist_track.trackid
    GROUP BY playlists.playlistid
    ORDER BY name
');
$stmt->execute([]);
$playlists = $stmt->fetchAll(PDO::FETCH_ASSOC);

$playlistID = -1;

if (isset($_GET['playlistID'])) {
    $playlistID = $_GET['playlistID'];
}

$stmt = $db->prepare('
    SELECT tracks.name AS track, albums.title AS album, artists.name AS artist, genres.name AS genre, tracks.milliseconds AS duration
    FROM playlist_track, tracks, albums, artists, genres
    WHERE playlist_track.playlistid = ?
    AND playlist_track.trackid = tracks.trackid
    AND albums.albumid = tracks.albumid
    AND artists.artistid = albums.artistid
    AND tracks.genreid = genres.genreid
');
$stmt->execute([$playlistID]);
$data = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>
<!doctype html>
<html>
    <head>
        <title>Chinook Mediendatenbank</title>
        <link rel="stylesheet" href="style.css" />
    </head>
    <body>
        <nav><?php include('menu.inc.php'); ?></nav>
        <main>
            <h2>Playlists</h2>
            <?php if (isset($_SESSION['user'])) { ?>               

                <form action="<?= $_SERVER['PHP_SELF']; ?>" method="get">
                    <label>
                        Playlist auswählen:
                        <select name="playlistID" onchange="this.form.submit()" autofocus>
                            <option value="-1" <?= $playlistID == -1 ? 'selected' : '' ?>>&raquo; bitte auswählen &laquo;</option>
                            <?php foreach ($playlists as $value) { ?>
                                <option value="<?= $value['PlaylistId'] ?>" <?= $playlistID == $value['PlaylistId'] ? 'selected' : '' ?>>
                                    <?= $value['Name'] ?> (<?= $value['TrackCount'] ?> Tracks, Dauer: <?= ms_to_timestamp($value['Duration']) ?>)
                                </option>
                            <?php } ?>
                        </select>
                    </label>
                </form>

                <p>&nbsp;</p>

                <table>
                    <tr>
                        <th>Track</th>
                        <th>Album</th>
                        <th>Artist</th>
                        <th>Genre</th>
                        <th>Duration</th>
                    </tr>
                    <?php foreach ($data as $value) { ?>
                        <tr>
                            <td><?= $value['track'] ?></td>
                            <td><a href="?album=<?= urlencode($value['album']) ?>"><?= $value['album'] ?></a></td>
                            <td><a href="?artist=<?= urlencode($value['artist']) ?>"><?= $value['artist'] ?></a></td>
                            <td><a href="?genre=<?= urlencode($value['genre']) ?>"><?= $value['genre'] ?></a></td>
                            <td><?= ms_to_timestamp($value['duration']) ?></td>
                        </tr>
                    <?php } ?>
            <?php } else { ?>
                Bitte <a href="login.php">anmelden</a>!
            <?php } ?>
        </main>
    </body>
</html>