<?php

require_once 'helpers.inc.php';

session_start();

$db = new PDO('sqlite:chinook.db');
$query = 'SELECT
    tracks.name AS track,
    albums.title AS album,
    artists.name AS artist,
    genres.name AS genre,
    tracks.milliseconds AS duration
FROM tracks, albums, artists, genres
WHERE tracks.albumid = albums.albumid
AND albums.artistid = artists.artistid
AND genres.genreid = tracks.genreid';
$parameters = array();

if (isset($_GET['artist'])) {
    $query .= ' AND artists.name = ?';
    $parameters[] = urldecode($_GET['artist']);
} 
if (isset($_GET['genre'])) {
    $query .= ' AND genres.name = ?';
    $parameters[] = urldecode($_GET['genre']);
} 
if (isset($_GET['album'])) {
    $query .= ' AND albums.title = ?';
    $parameters[] = urldecode($_GET['album']);
}

$stmt = $db->prepare($query);
$stmt->execute($parameters);
$data = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>
<!doctype html>
<html>
    <head>
        <meta charset="utf-8" />
        <title>Chinook Tracks</title>
        <link rel="stylesheet" href="style.css" />
    </head>
    <body>
        <nav><?php include('menu.inc.php'); ?></nav>
        <main>
            <h2>Chinook Tracks</h2>
            <?php if (isset($_SESSION['user'])) { ?>
                <table>
                    <tr>
                        <th>Track</th>
                        <th>Album</th>
                        <th>Artist</th>
                        <th>Genre</th>
                        <th>Duration</th>
                    </tr>
                    <?php foreach ($data as $value) { ?>
                        <tr>
                            <td><?= $value['track'] ?></td>
                            <td><a href="?album=<?= urlencode($value['album']) ?>"><?= $value['album'] ?></a></td>
                            <td><a href="?artist=<?= urlencode($value['artist']) ?>"><?= $value['artist'] ?></a></td>
                            <td><a href="?genre=<?= urlencode($value['genre']) ?>"><?= $value['genre'] ?></a></td>
                            <td><?= ms_to_timestamp($value['duration']) ?></td>
                        </tr>
                    <?php } ?>
                </table>
            <?php } else { ?>
                Bitte <a href="login.php">anmelden</a>!
            <?php } ?>
        </main>
    </body>
</html>